@@ -1,3 +1,3 @@
-#error "/home/espenr/tmp/qt-3-espenr-28736/qt/extensions/nsplugin/src/npapi.h must be provided by Netscape"
+#error "/home/espenr/tmp/qt-3.3.8-espenr-2499/qt/extensions/nsplugin/src/npapi.h must be provided by Netscape"
 #error "This file is just a placeholder. Please see the documentation"
 #error "to learn how to obtain the real file"
