@@ -1,16 +1,16 @@
 /****************************************************************************
-** $Id: qt/qrichtext_p.h   3.3.7   edited Aug 31 2005 $
+** $Id: qt/qrichtext_p.h   3.3.8   edited Jan 11 14:46 $
 **
 ** Definition of internal rich text classes
 **
 ** Created : 990124
 **
-** Copyright (C) 1999-2005 Trolltech AS.  All rights reserved.
+** Copyright (C) 1999-2007 Trolltech ASA.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
 ** This file may be distributed under the terms of the Q Public License
-** as defined by Trolltech AS of Norway and appearing in the file
+** as defined by Trolltech ASA of Norway and appearing in the file
 ** LICENSE.QPL included in the packaging of this file.
 **
 ** This file may be distributed and/or modified under the terms of the
@@ -738,6 +738,7 @@ private:
     int stretch;
     int innerborder;
     int us_cp, us_ib, us_b, us_ob, us_cs;
+    int us_fixwidth;
     QMap<QString, QString> attributes;
     QMap<QTextCursor*, int> currCell;
     Placement place;
