@@ -5,16 +5,15 @@
 #define QT_PRODUCT_LICENSE  "qt-free"
 
 /* Build key */
-#define QT_BUILD_KEY "macppc OpenBSD g++-3.* full-config"
+#define QT_BUILD_KEY "amd64 OpenBSD g++-OpenBSD clang version 6.0.0 (tags/RELEASE_600/final) (based on LLVM 6.0.0) Target: amd64-unknown-openbsd6.4 Thread model: posix InstalledDir: /usr/bin full-config"
 
 /* Machine byte-order */
 #define Q_BIG_ENDIAN 4321
 #define Q_LITTLE_ENDIAN 1234
-#define Q_BYTE_ORDER Q_BIG_ENDIAN
-
+#define Q_BYTE_ORDER Q_LITTLE_ENDIAN
 /* Compile time features */
 #define QT_LARGEFILE_SUPPORT 64
-#define QT_POINTER_SIZE 4
+#define QT_POINTER_SIZE 8
 #ifndef QT_NO_IM_EXTENSIONS
 # define QT_NO_IM_EXTENSIONS
 #endif
