@@ -1,16 +1,16 @@
 /****************************************************************************
-** $Id: qt/qwidget.h   3.3.7   edited Aug 31 2005 $
+** $Id: qt/qwidget.h   3.3.8   edited Jan 11 14:38 $
 **
 ** Definition of QWidget class
 **
 ** Created : 931029
 **
-** Copyright (C) 1992-2005 Trolltech AS.  All rights reserved.
+** Copyright (C) 1992-2007 Trolltech ASA.  All rights reserved.
 **
 ** This file is part of the kernel module of the Qt GUI Toolkit.
 **
 ** This file may be distributed under the terms of the Q Public License
-** as defined by Trolltech AS of Norway and appearing in the file
+** as defined by Trolltech ASA of Norway and appearing in the file
 ** LICENSE.QPL included in the packaging of this file.
 **
 ** This file may be distributed and/or modified under the terms of the
@@ -988,6 +988,9 @@ struct Q_EXPORT QTLWExtra {
     HICON    winIcon;				// internal Windows icon
 #endif
     QRect    normalGeometry;			// used by showMin/maximized/FullScreen
+#ifdef Q_WS_WIN
+    uint style, exstyle;
+#endif
 };
 
 
